@@ -1,3 +1,6 @@
+#ifndef QT_FEATURES_WebEngineCore_src_core_api_qtwebenginecore_config_p_h_H
+#define QT_FEATURES_WebEngineCore_src_core_api_qtwebenginecore_config_p_h_H
+
 #define QT_FEATURE_webengine_embedded_build -1
 
 #define QT_FEATURE_webengine_system_alsa -1
@@ -8,6 +11,8 @@
 
 #define QT_FEATURE_webengine_system_gbm 1
 
+#define QT_FEATURE_webengine_webrtc_system_openh264 1
+
 #define QT_FEATURE_webengine_printing_and_pdf 1
 
 #define QT_FEATURE_webengine_system_sndio 1
@@ -30,5 +35,7 @@
 
 #define QT_FEATURE_webengine_vaapi -1
 
-#define QT_FEATURE_webengine_system_poppler 1
+#define QT_FEATURE_webengine_arm64_udot_support -1
 
+
+#endif // QT_FEATURES_WebEngineCore_src_core_api_qtwebenginecore_config_p_h_H
